@@ -6,6 +6,10 @@ import sys
 import unittest
 from email import message_from_string
 
+import docutils.parsers.rst
+import docutils.utils
+import docutils.frontend
+
 import piplicenses
 from piplicenses import (__pkgname__, create_parser, output_colored,
                          create_licenses_table, get_output_fields, get_sortby,
@@ -17,6 +21,23 @@ from piplicenses import (__pkgname__, create_parser, output_colored,
                          LICENSE_UNKNOWN)
 
 
+UNICODE_APPENDIX = ""
+with open('tests/fixtures/unicode_characters.txt', encoding='utf-8') as f:
+    # Read from external file considering a terminal that cannot handle "emoji"
+    UNICODE_APPENDIX = f.readline().replace("\n", "")
+
+
+def get_installed_distributions_mocked(*args, **kwargs):
+    packages = get_installed_distributions_orig(*args, **kwargs)
+    if not packages[-1].project_name.endswith(UNICODE_APPENDIX):
+        packages[-1].project_name += " "+UNICODE_APPENDIX
+    return packages
+
+
+get_installed_distributions_orig = piplicenses.get_installed_distributions
+piplicenses.get_installed_distributions = get_installed_distributions_mocked
+
+
 class CommandLineTestCase(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
@@ -47,6 +68,18 @@ class TestGetLicenses(CommandLineTestCase):
 
         return pkg_name_columns
 
+    # from https://stackoverflow.com/questions/12883428/ ...
+    # ... how-to-parse-restructuredtext-in-python
+    @staticmethod
+    def check_rst(text: str):
+        parser = docutils.parsers.rst.Parser()
+        components = (docutils.parsers.rst.Parser,)
+        settings = docutils.frontend.\
+            OptionParser(components=components).get_default_values()
+        settings.halt_level = 3
+        document = docutils.utils.new_document('<rst-doc>', settings=settings)
+        parser.parse(text, document)
+
     def test_with_empty_args(self):
         empty_args = []
         args = self.parser.parse_args(empty_args)
@@ -322,7 +355,7 @@ class TestGetLicenses(CommandLineTestCase):
     def test_format_markdown(self):
         format_markdown_args = ['--format=markdown']
         args = self.parser.parse_args(format_markdown_args)
-        table = factory_styled_table_with_args(args)
+        table = create_licenses_table(args)
 
         self.assertIn('l', table.align.values())
         self.assertTrue(table.border)
@@ -330,21 +363,37 @@ class TestGetLicenses(CommandLineTestCase):
         self.assertEqual('|', table.junction_char)
         self.assertEqual(RULE_HEADER, table.hrules)
 
-    def test_format_rst(self):
+    @unittest.skipIf(sys.version_info < (3, 6, 0),
+                     "To unsupport Python 3.5 in the near future")
+    def test_format_rst_without_filter(self):
         format_rst_args = ['--format=rst']
         args = self.parser.parse_args(format_rst_args)
-        table = factory_styled_table_with_args(args)
+        table = create_licenses_table(args)
 
         self.assertIn('l', table.align.values())
         self.assertTrue(table.border)
         self.assertTrue(table.header)
         self.assertEqual('+', table.junction_char)
         self.assertEqual(RULE_ALL, table.hrules)
+        with self.assertRaises(docutils.utils.SystemMessage):
+            self.check_rst(str(table))
+
+    def test_format_rst_default_filter(self):
+        format_rst_args = ['--format=rst', '--filter-strings']
+        args = self.parser.parse_args(format_rst_args)
+        table = create_licenses_table(args)
+
+        self.assertIn('l', table.align.values())
+        self.assertTrue(table.border)
+        self.assertTrue(table.header)
+        self.assertEqual('+', table.junction_char)
+        self.assertEqual(RULE_ALL, table.hrules)
+        self.check_rst(str(table))
 
     def test_format_confluence(self):
         format_confluence_args = ['--format=confluence']
         args = self.parser.parse_args(format_confluence_args)
-        table = factory_styled_table_with_args(args)
+        table = create_licenses_table(args)
 
         self.assertIn('l', table.align.values())
         self.assertTrue(table.border)
@@ -444,6 +493,27 @@ class TestGetLicenses(CommandLineTestCase):
         self.assertIn(text, actual)
         self.assertTrue(actual.endswith('\033[0m'))
 
+    def test_without_filter(self):
+        args = self.parser.parse_args([])
+        packages = list(piplicenses.get_packages(args))
+        self.assertIn(UNICODE_APPENDIX, packages[-1]["name"])
+
+    def test_with_default_filter(self):
+        args = self.parser.parse_args(["--filter-strings"])
+        packages = list(piplicenses.get_packages(args))
+        self.assertNotIn(UNICODE_APPENDIX, packages[-1]["name"])
+
+    def test_with_specified_filter(self):
+        args = self.parser.parse_args(["--filter-strings",
+                                       "--filter-code-page=ascii"])
+        packages = list(piplicenses.get_packages(args))
+        self.assertNotIn(UNICODE_APPENDIX, packages[-1]["summary"])
+
+    def test_invalid_code_page(self):
+        with self.assertRaises(SystemExit):
+            self.parser.parse_args(["--filter-strings",
+                                    "--filter-code-page=XXX"])
+
 
 class MockStdStream(object):
 
